@@ -31,7 +31,7 @@ from numba.cuda.core.errors import (
 from numba.cuda.core.funcdesc import default_mangler
 from numba.cuda.core.environment import Environment
 from numba.cuda.core.analysis import compute_use_defs, must_use_alloca
-from numba.cuda.misc.firstlinefinder import get_func_body_first_lineno
+from numba.cuda.misc.firstlinefinder import get_func_def_lineno
 from numba.cuda.misc.coverage_support import get_registered_loc_notify
 
 
@@ -125,11 +125,10 @@ class BaseLower(object):
         defn_loc = self.func_ir.loc.with_lineno(self.func_ir.loc.line + 1)
         if self.context.enable_debuginfo:
             fn = self.func_ir.func_id.func
-            optional_lno = get_func_body_first_lineno(fn)
+            optional_lno = get_func_def_lineno(fn)
             if optional_lno is not None:
-                # -1 as lines start at 1 and this is an offset.
-                offset = optional_lno - 1
-                defn_loc = self.func_ir.loc.with_lineno(offset)
+                # Use the def line directly from AST
+                defn_loc = self.func_ir.loc.with_lineno(optional_lno)
             else:
                 msg = (
                     "Could not find source for function: "
@@ -139,6 +138,16 @@ class BaseLower(object):
                 warnings.warn(NumbaDebugInfoWarning(msg))
         return defn_loc
 
+    def _adjust_line_if_prologue(self, line):
+        """Adjust prologue line numbers to use the 'def' line.
+
+        The function prologue doesn't have corresponding source lines. These
+        instructions inherit line numbers from co_firstlineno, which points to
+        the decorator line when decorators are present. This method redirects
+        such lines to the 'def' line.
+        """
+        return self.defn_loc.line if line < self.defn_loc.line else line
+
     def pre_lower(self):
         """
         Called before lowering all blocks.
@@ -504,7 +513,9 @@ class Lower(BaseLower):
 
     def lower_inst(self, inst):
         # Set debug location for all subsequent LL instructions
-        self.debuginfo.mark_location(self.builder, self.loc.line)
+        self.debuginfo.mark_location(
+            self.builder, self._adjust_line_if_prologue(self.loc.line)
+        )
         self.notify_loc(self.loc)
         self.debug_print(str(inst))
         if isinstance(inst, ir.assign_types):
@@ -1660,7 +1671,7 @@ class Lower(BaseLower):
                     name=name,
                     lltype=lltype,
                     size=sizeof,
-                    line=self.loc.line,
+                    line=self._adjust_line_if_prologue(self.loc.line),
                     datamodel=datamodel,
                 )
         return aptr
@@ -1748,7 +1759,7 @@ class CUDALower(Lower):
             if isinstance(lltype, int_type + real_type):
                 sizeof = self.context.get_abi_sizeof(lltype)
                 datamodel = self.context.data_model_manager[fetype]
-                line = self.loc.line if argidx is None else self.defn_loc.line
+                line = self._adjust_line_if_prologue(self.loc.line)
                 if not name.startswith("$"):
                     # Emit debug value for user variable
                     src_name = name.split(".")[0]
